package com.ruoyi.oa.service;

import java.util.List;
import com.ruoyi.oa.domain.CmcResourceField;

/**
 * 专业领域Service接口
 * 
 * @author cmc
 * @date 2025-03-21
 */
public interface ICmcResourceFieldService
{
    /**
     * 查询专业领域
     * 
     * @param fieldId 专业领域主键
     * @return 专业领域
     */
    public CmcResourceField selectCmcResourceFieldByFieldId(Integer fieldId);

    /**
     * 查询专业领域列表
     * 
     * @param cmcResourceField 专业领域
     * @return 专业领域集合
     */
    public List<CmcResourceField> selectCmcResourceFieldList(CmcResourceField cmcResourceField);

    /**
     * 新增专业领域
     * 
     * @param cmcResourceField 专业领域
     * @return 结果
     */
    public int insertCmcResourceField(CmcResourceField cmcResourceField);

    /**
     * 修改专业领域
     * 
     * @param cmcResourceField 专业领域
     * @return 结果
     */
    public int updateCmcResourceField(CmcResourceField cmcResourceField);

    /**
     * 批量删除专业领域
     * 
     * @param fieldIds 需要删除的专业领域主键集合
     * @return 结果
     */
    public int deleteCmcResourceFieldByFieldIds(Integer[] fieldIds);

    /**
     * 删除专业领域信息
     * 
     * @param fieldId 专业领域主键
     * @return 结果
     */
    public int deleteCmcResourceFieldByFieldId(Integer fieldId);
}
